pub struct DeviceFlag(/* private fields */);Implementations
Sourceimpl DeviceFlag
impl DeviceFlag
Sourcepub const READONLY: DeviceFlag
pub const READONLY: DeviceFlag
All writes to the block device will fail.
Sourcepub const REMOVABLE: DeviceFlag
pub const REMOVABLE: DeviceFlag
The block device may be removed from the device during operation.
Sourcepub const TRIM_SUPPORT: DeviceFlag
pub const TRIM_SUPPORT: DeviceFlag
The device provides trim support.
Sourcepub const FUA_SUPPORT: DeviceFlag
pub const FUA_SUPPORT: DeviceFlag
The device provides Force Unit Access (FUA) support.
If this bit is unset, and a request is sent with the FORCE_ACCESS option set, the device will simulate a FUA by executing a device flush after the request completes (but before responding to the client). Clients are strongly encouraged to probe for FUA support and avoid usage of FORCE_ACCESS without device support, since this is expensive.
Sourcepub const ZSTD_DECOMPRESSION_SUPPORT: DeviceFlag
pub const ZSTD_DECOMPRESSION_SUPPORT: DeviceFlag
The device provides zstd decompression support.
Sourcepub const BARRIER_SUPPORT: DeviceFlag
pub const BARRIER_SUPPORT: DeviceFlag
The device provides Barrier support.
If this bit is unset, and a request is sent with the PRE_BARRIER option set, the device will simulate a barrier by executing a device flush before the request is submitted. Clients are strongly encouraged to probe for barrier support and avoid usage of PRE_BARRIER without device support, since this is expensive.
Sourceimpl DeviceFlag
impl DeviceFlag
Sourcepub const fn empty() -> DeviceFlag
pub const fn empty() -> DeviceFlag
Get a flags value with all bits unset.
Sourcepub const fn all() -> DeviceFlag
pub const fn all() -> DeviceFlag
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<DeviceFlag>
pub const fn from_bits(bits: u32) -> Option<DeviceFlag>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> DeviceFlag
pub const fn from_bits_truncate(bits: u32) -> DeviceFlag
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> DeviceFlag
pub const fn from_bits_retain(bits: u32) -> DeviceFlag
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DeviceFlag>
pub fn from_name(name: &str) -> Option<DeviceFlag>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DeviceFlag) -> bool
pub const fn intersects(&self, other: DeviceFlag) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: DeviceFlag) -> bool
pub const fn contains(&self, other: DeviceFlag) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: DeviceFlag)
pub fn insert(&mut self, other: DeviceFlag)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: DeviceFlag)
pub fn remove(&mut self, other: DeviceFlag)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DeviceFlag)
pub fn toggle(&mut self, other: DeviceFlag)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: DeviceFlag, value: bool)
pub fn set(&mut self, other: DeviceFlag, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DeviceFlag) -> DeviceFlag
pub const fn intersection(self, other: DeviceFlag) -> DeviceFlag
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: DeviceFlag) -> DeviceFlag
pub const fn union(self, other: DeviceFlag) -> DeviceFlag
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: DeviceFlag) -> DeviceFlag
pub const fn difference(self, other: DeviceFlag) -> DeviceFlag
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: DeviceFlag) -> DeviceFlag
pub const fn symmetric_difference(self, other: DeviceFlag) -> DeviceFlag
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> DeviceFlag
pub const fn complement(self) -> DeviceFlag
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl DeviceFlag
impl DeviceFlag
Sourcepub const fn iter(&self) -> Iter<DeviceFlag>
pub const fn iter(&self) -> Iter<DeviceFlag>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DeviceFlag>
pub const fn iter_names(&self) -> IterNames<DeviceFlag>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.