pub struct SessionProxy { /* private fields */ }Implementations
Sourceimpl SessionProxy
impl SessionProxy
Sourcepub fn take_event_stream(&self) -> SessionEventStream
pub fn take_event_stream(&self) -> SessionEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn close(
&self,
) -> QueryResponseFut<CloseableCloseResult, FDomainResourceDialect>
pub fn close( &self, ) -> QueryResponseFut<CloseableCloseResult, FDomainResourceDialect>
Terminates the connection.
After calling Close, the client must not send any other requests.
Servers, after sending the status response, should close the connection regardless of status and without sending an epitaph.
Closing the client end of the channel should be semantically equivalent
to calling Close without knowing when the close has completed or its
status.
Sourcepub fn get_fifo(
&self,
) -> QueryResponseFut<SessionGetFifoResult, FDomainResourceDialect>
pub fn get_fifo( &self, ) -> QueryResponseFut<SessionGetFifoResult, FDomainResourceDialect>
Returns a handle to the client end of the FIFO.
Sourcepub fn attach_vmo(
&self,
vmo: Vmo,
) -> QueryResponseFut<SessionAttachVmoResult, FDomainResourceDialect>
pub fn attach_vmo( &self, vmo: Vmo, ) -> QueryResponseFut<SessionAttachVmoResult, FDomainResourceDialect>
Attaches a VMO to the session.
Returns an identifer that can be used to refer to the VMO.